The highest tagged major version is
v2.
package
Version:
v0.0.0-...-9370983
Opens a new window with list of versions in this module.
Published: Dec 24, 2021
License: GPL-3.0
Opens a new window with license information.
Imports: 15
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Add adds tcpConn to tcpQueue.
AddPacket adds udpPacket to udpQueue.
func SetUDPTimeout(v int)
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.